@@ -276,7 +276,7 @@ class Flow(object):
 
         Returns:
             Mapping[str, str]: The obtained tokens. Typically, you will not use
-                return value of this function and instead and use
+                return value of this function and instead use
                 :meth:`credentials` to obtain a
                 :class:`~google.auth.credentials.Credentials` instance.
         """
@@ -378,6 +378,8 @@ class InstalledAppFlow(Flow):
         open_browser=True,
         redirect_uri_trailing_slash=True,
         timeout_seconds=None,
+        token_audience=None,
+        browser=None,
         **kwargs
     ):
         """Run the flow using the server strategy.
@@ -412,6 +414,11 @@ class InstalledAppFlow(Flow):
                 if there are no credentials response. The value is in seconds.
                 When set to None there is no timeout.
                 Default value is None.
+            token_audience (str): Passed along with the request for an access
+                token. Determines the endpoints with which the token can be
+                used. Optional.
+            browser (str): specify which browser to open for authentication. If not
+                specified this defaults to default browser.
             kwargs: Additional keyword arguments passed through to
                 :meth:`authorization_url`.
 
@@ -433,7 +440,8 @@ class InstalledAppFlow(Flow):
         auth_url, _ = self.authorization_url(**kwargs)
 
         if open_browser:
-            webbrowser.open(auth_url, new=1, autoraise=True)
+            # if browser is None it defaults to default browser
+            webbrowser.get(browser).open(auth_url, new=1, autoraise=True)
 
         if authorization_prompt_message:
             print(authorization_prompt_message.format(url=auth_url))
@@ -444,7 +452,9 @@ class InstalledAppFlow(Flow):
         # Note: using https here because oauthlib is very picky that
         # OAuth 2.0 should only occur over https.
         authorization_response = wsgi_app.last_request_uri.replace("http", "https")
-        self.fetch_token(authorization_response=authorization_response)
+        self.fetch_token(
+            authorization_response=authorization_response, audience=token_audience
+        )
 
         # This closes the socket
         local_server.server_close()
